﻿using System;
using System.Collections.Generic;

class SequenceOfMarines
{
    static void Main()
    {
        char[] marines = Console.ReadLine().ToCharArray();

        //long sequencesCountSlow = CountSequencesSlow(marines);
        //Console.WriteLine("Slow: " + sequencesCountSlow);

        //long sequencesCountOverflow = CountSequencesOverflow(marines);
        //Console.WriteLine("Overflow: " + sequencesCountOverflow);

        long sequencesCount = CountSequencesFast(marines);
        Console.WriteLine(sequencesCount);
    }

    private static long CountSequencesSlow(char[] marines)
    {
        HashSet<string> sequences = new HashSet<string>();
        GenerateAllPermutations(marines, 0, sequences);
        foreach (var s in sequences)
        {
            Console.WriteLine(s);
        }
        return sequences.Count;
    }

    private static void GenerateAllPermutations(
        char[] marines, int start, HashSet<string> sequences)
    {
        if (start == marines.Length - 1)
        {
            sequences.Add(new String(marines));
            return;
        }
        GenerateAllPermutations(marines, start + 1, sequences);
        for (int i = start; i < marines.Length; i++)
        {
            Swap(ref marines[start], ref marines[i]);
            GenerateAllPermutations(marines, start + 1, sequences);
            Swap(ref marines[start], ref marines[i]);
        }
    }

    private static void Swap<T>(ref T first, ref T second)
    {
        T old = first;
        first = second;
        second = old;
    }

    private static long CountSequencesOverflow(char[] marines)
    {
        // We calculate directly the formula n! / (c1! * c2! * ... ck!)
        // where c1, c2, .. ck are the number of the marines fo each color

        int n = marines.Length;
        long result = Factorial(n);

        int[] marineCounts = new int['Z' + 1];
        foreach (var marine in marines)
        {
            marineCounts[marine]++;
        }

        for (int i = 'A'; i <= 'Z'; i++)
        {
            int marinesOfCertainColor = marineCounts[i];
            long factorial = Factorial(marinesOfCertainColor);
            result /= factorial;
        }

        return result;
    }

    private static long Factorial(int n)
    {
        long result = 1;
        for (int i = 2; i <= n; i++)
        {
            result *= i;
        }

        return result;
    }

    private static long CountSequencesFast(char[] marines)
    {
        // We calculate smartly the formula n! / (c1! * c2! * ... ck!)
        // where c1, c2, .. ck are the number of the marines fo each color

        int n = marines.Length;

        // Collect the divisors of all numerators
        int[] numerators = new int[n + 1];
        for (int i = 2; i <= n; i++)
        {
            AddDivisors(i, numerators);
        }

        // Collect the divisors of all denominators
        int[] marineCounts = new int['Z' + 1];
        foreach (var marine in marines)
        {
            marineCounts[marine]++;
        }

        int[] denominators = new int[n + 1];
        for (int i = 'A'; i <= 'Z'; i++)
        {
            int marinesOfCertainColor = marineCounts[i];
            for (int count = 2; count <= marinesOfCertainColor; count++)
            {
                AddDivisors(count, denominators);
            }
        }

        // Use C# keyword "checked" to ensure integer overflow is not possible
        checked
        {
            // Smartly multiply all numerators and divide by all denominators
            long result = 1;
            for (int div = 2; div <= n; div++)
            {
                int count = numerators[div] - denominators[div];
                for (int i = 0; i < count; i++)
                {
                    result *= div;
                }
            }

            return result;
        }
    }

    private static void AddDivisors(int n, int[] divisors)
    {
        // Extract all prime divisors of given number N and
        // increase the count of each divisors in the given array

        int div = 2;
        while (n > 1)
        {
            if (n % div == 0)
            {
                divisors[div]++;
                n = n / div;
            }
            else
            {
                div++;
            }
        }
    }
}
